# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/55_nbks.ipynb.

# %% auto 0
__all__ = ['NB', 'NBS', 'CELL', 'CODE', 'LINE', 'CELLS', 'SHELL', 'SOURCE', 'NOTEBOOK', 'NOTEBOOKS', 'CELL_TYPE', 'HTML', 'LEXER',
           'MODULE', 'IPYTHON', 'FORMATTER', 'GET_IPYTHON']

# %% ../nbs/55_nbks.ipynb 4
from .args import TYPE

# %% ../nbs/55_nbks.ipynb 5
NB = 'nb'
NBS = f'{NB}s'
CELL = 'cell'

CODE = 'code'
LINE = 'line'

CELLS = f'{CELL}s'
SHELL = 'shell'

SOURCE = 'source'

NOTEBOOK = 'notebook'
NOTEBOOKS = f'{NOTEBOOK}s'

CELL_TYPE = f'{CELL}_{TYPE}'

# %% ../nbs/55_nbks.ipynb 6
HTML = 'html'
LEXER = 'lexer'
MODULE = 'module'
IPYTHON = 'ipython'
FORMATTER = 'formatter'
GET_IPYTHON = f'get_{IPYTHON}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/92_byte.ipynb.

# %% auto 0
__all__ = ['B', 'BYTE', 'BYTES', 'KILOBYTE', 'MEGABYTE', 'GIGABYTE', 'TERABYTE', 'PETABYTE', 'EXABYTE', 'ZETTABYTE', 'YOTTABYTE',
           'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB', 'BYTE_UNITS', 'BYTE_SYMBS']

# %% ../nbs/92_byte.ipynb 4
from nlit.unit import (
    k, M, G, T, P, E, Z, Y,
    KILO, MEGA, GIGA, TERA, PETA, EXA, ZETTA, YOTTA,
)

# %% ../nbs/92_byte.ipynb 6
B     = 'B'
BYTE  = 'byte'
BYTES = f'{BYTE}s'

# %% ../nbs/92_byte.ipynb 8
KILOBYTE  = f'{KILO}{BYTE}'
MEGABYTE  = f'{MEGA}{BYTE}'
GIGABYTE  = f'{GIGA}{BYTE}'
TERABYTE  = f'{TERA}{BYTE}'
PETABYTE  = f'{PETA}{BYTE}'
EXABYTE   = f'{EXA}{BYTE}'
ZETTABYTE = f'{ZETTA}{BYTE}'
YOTTABYTE = f'{YOTTA}{BYTE}'

# %% ../nbs/92_byte.ipynb 10
KB = f'{k}{B}'
MB = f'{M}{B}'
GB = f'{G}{B}'
TB = f'{T}{B}'
PB = f'{P}{B}'
EB = f'{E}{B}'
ZB = f'{Z}{B}'
YB = f'{Y}{B}'

# %% ../nbs/92_byte.ipynb 13
BYTE_UNITS = (BYTE, KILOBYTE, MEGABYTE, GIGABYTE, TERABYTE, PETABYTE, EXABYTE, ZETTABYTE, YOTTABYTE, )

# %% ../nbs/92_byte.ipynb 15
BYTE_SYMBS = (B, KB, MB, GB, TB, PB, EB, ZB, YB, )



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/60_narr.ipynb.

# %% auto 0
__all__ = ['NDIM', 'DIMS', 'DTYPE', 'SHAPE', 'ARRAY', 'TOARRAY', 'TODENSE', 'TOLIST', 'MIN', 'MAX', 'SUM', 'STD', 'VAR', 'NORM',
           'MEAN', 'MEDIAN', 'CENTROID']

# %% ../nbs/60_narr.ipynb 5
NDIM = 'ndim'
DIMS = 'dims'

DTYPE = 'dtype'
SHAPE = 'shape'

ARRAY = 'array'

TOARRAY = 'toarray'
TODENSE = 'todense'
TOLIST = 'tolist'

# %% ../nbs/60_narr.ipynb 6
MIN = 'min'
MAX = 'max'
SUM = 'sum'
STD = 'std'
VAR = 'var'
NORM = 'norm'
MEAN = 'mean'
MEDIAN = 'median'
CENTROID = 'centroid'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/61_tens.ipynb.

# %% auto 0
__all__ = ['DETACH', 'DEVICE', 'INT8', 'INT16', 'INT32', 'INT64', 'UINT8', 'UINT16', 'UINT32', 'UINT64', 'FLOAT16', 'FLOAT32',
           'FLOAT64', 'FLOAT128', 'COMPLEX64', 'COMPLEX128', 'COMPLEX256', 'CUDA', 'MPS', 'CPU', 'IPU', 'XPU', 'TPU',
           'MKLDNN', 'OPENGL', 'OPENCL', 'VULKAN', 'IDEEP', 'HIP', 'VE', 'FPGA', 'ORT', 'XLA', 'LAZY', 'META', 'HPU',
           'PRIVATEUSEONE', 'NCCL', 'CUDNN', 'NVIDIA', 'CLONE', 'NUMPY', 'ACC', 'ACCEL', 'ACCELERATORS', 'EYE', 'DIRAC',
           'ZEROS', 'NORMAL', 'SPARSE', 'UNIFORM', 'CONSTANT', 'ORTHOGONAL', 'XAVIER', 'KAIMING', 'XAVIER_NORMAL',
           'KAIMING_NORMAL', 'XAVIER_UNIFORM', 'ELU', 'LOG', 'MIN', 'MAX', 'HARD', 'SOFT', 'PLUS', 'RELU', 'TANH',
           'LEAKY', 'SWISH', 'SHRINK', 'SIGMOID', 'MULTI', 'HEAD', 'ATT', 'ATTENTION', 'HARDTANH', 'HARDSWISH',
           'HARDSHRINK', 'HARDSIGMOID', 'SOFTMIN', 'SOFTMAX', 'SOFTPLUS', 'SOFTMAX2D', 'SOFTSHRINK', 'LEAKYRELU',
           'LOGSOFTMAX', 'LOGSIGMOID', 'MULTIHEADATTENTION', 'GLU', 'SELU', 'CELU', 'GELU', 'PRELU', 'SILU', 'MISH',
           'TANHSHRINK', 'THRESHOLD', 'ADAPTIVELOGSOFTMAXWITHLOSS', 'TCHW', 'THWC', 'NUM', 'PAD', 'PROJ', 'LAYER',
           'LAYERS', 'SIZE', 'INPUT', 'HIDDEN', 'OUTPUT', 'INPUT_SIZE', 'HIDDEN_SIZE', 'OUTPUT_SIZE', 'NUM_LAYERS',
           'BIAS', 'BATCH', 'BATCH_SIZE', 'BATCH_FIRST', 'DROPOUT', 'BIDIRECTIONAL', 'PROJ_SIZE', 'NONLINEARITY',
           'IS2D', 'INIT', 'NINIT', 'N_INIT', 'IS_BUILT', 'IS_AVAILABLE', 'SEED', 'SEEDS', 'SEEDED']

# %% ../nbs/61_tens.ipynb 4
from .args import IS

# %% ../nbs/61_tens.ipynb 6
DETACH = 'detach'
DEVICE = 'device'

# %% ../nbs/61_tens.ipynb 7
INT8 = 'int8'
INT16 = 'int16'
INT32 = 'int32'
INT64 = 'int64'
UINT8 = 'uint8'
UINT16 = 'uint16'
UINT32 = 'uint32'
UINT64 = 'uint64'
FLOAT16 = 'float16'
FLOAT32 = 'float32'
FLOAT64 =  'float64'
FLOAT128 = 'float128'
COMPLEX64 = 'complex64'
COMPLEX128 = 'complex128'
COMPLEX256 = 'complex256'


# %% ../nbs/61_tens.ipynb 9
CUDA = 'cuda'
MPS = 'mps'
CPU = 'cpu'
IPU = 'ipu'
XPU = 'xpu'
TPU = 'tpu'
MKLDNN = 'mkldnn'
OPENGL = 'opengl'
OPENCL = 'opencl'
VULKAN = 'vulkan'
IDEEP = 'ideep'
HIP = 'hip'
VE = 've'
FPGA = 'fpga'
ORT = 'ort'
XLA = 'xla'
LAZY = 'lazy'
META = 'meta'
HPU = 'hpu'
PRIVATEUSEONE = 'privateuseone'

# %% ../nbs/61_tens.ipynb 11
NCCL = 'nccl'
CUDNN = 'cudnn'
NVIDIA = 'nvidia'

# %% ../nbs/61_tens.ipynb 13
CLONE = 'clone'
NUMPY = 'numpy'

# %% ../nbs/61_tens.ipynb 15
ACC = 'acc'
ACCEL = f'{ACC}el'
ACCELERATORS = f'{ACCEL}erators'

# %% ../nbs/61_tens.ipynb 18
EYE = 'eye'
DIRAC = 'dirac'
ZEROS = 'zeros'
NORMAL =  'normal'
SPARSE = 'sparse'
UNIFORM = 'uniform'
CONSTANT = 'constant'
ORTHOGONAL = 'orthogonal'

XAVIER = 'xavier'
KAIMING = 'kaiming'

XAVIER_NORMAL = f'{XAVIER}_{NORMAL}'
KAIMING_NORMAL = f'{KAIMING}_{NORMAL}'
XAVIER_UNIFORM = f'{XAVIER}_{UNIFORM}'

# %% ../nbs/61_tens.ipynb 20
ELU = 'elu'
LOG = 'log'

MIN = 'min'
MAX = 'max'
HARD = 'hard'
SOFT = 'soft'
PLUS = 'plus'

RELU = f'r{ELU}'
TANH = 'tanh'

LEAKY = 'leaky'
SWISH = 'swish'

SHRINK = 'shrink'
SIGMOID = 'sigmoid'

MULTI = 'multi'
HEAD = 'head'

ATT = 'att'
ATTENTION = f'{ATT}ention'

# %% ../nbs/61_tens.ipynb 21
HARDTANH = f'{HARD}{TANH}'
HARDSWISH = f'{HARD}{SWISH}'
HARDSHRINK = f'{HARD}{SHRINK}'
HARDSIGMOID = f'{HARD}{SIGMOID}'

SOFTMIN = f'{SOFT}{MIN}'
SOFTMAX = f'{SOFT}{MAX}'
SOFTPLUS = f'{SOFT}{PLUS}'
SOFTMAX2D = f'{SOFTMAX}2d'
SOFTSHRINK = f'{SOFT}{SHRINK}'

LEAKYRELU = f'{LEAKY}{RELU}'

LOGSOFTMAX = f'{LOG}{SOFTMAX}'
LOGSIGMOID = f'{LOG}{SIGMOID}'

MULTIHEADATTENTION = f'{MULTI}{HEAD}{ATTENTION}'

GLU = 'glu'

SELU = f's{ELU}'
CELU = f'c{ELU}'
GELU = f'g{ELU}'
PRELU = f'p{RELU}'

SILU = 'silu'
MISH = 'mish'

TANHSHRINK = f'{TANH}{SHRINK}'

THRESHOLD = 'threshold'

ADAPTIVELOGSOFTMAXWITHLOSS = f'adaptive{LOGSOFTMAX}withloss'

# %% ../nbs/61_tens.ipynb 23
TCHW = 'tchw'
THWC = 'thwc'

# %% ../nbs/61_tens.ipynb 25
NUM = 'num'

PAD = 'pad'

PROJ = 'proj'
LAYER = 'layer'
LAYERS = f'{LAYER}s'

SIZE = 'size'
INPUT = 'input'
HIDDEN = 'hidden'
OUTPUT = 'output'
INPUT_SIZE = f'{INPUT}_{SIZE}'
HIDDEN_SIZE = f'{HIDDEN}_{SIZE}'
OUTPUT_SIZE = f'{OUTPUT}_{SIZE}'

NUM_LAYERS = f'{NUM}_{LAYERS}'
BIAS = 'bias'
BATCH = 'batch'
BATCH_SIZE = f'{BATCH}_{SIZE}'
BATCH_FIRST = f'{BATCH}_first'


DROPOUT = 'dropout'
BIDIRECTIONAL = 'bidirectional'
PROJ_SIZE = f'{PROJ}_{SIZE}'
NONLINEARITY = 'nonlinearity'

# %% ../nbs/61_tens.ipynb 27
IS2D = f'{IS}2d'
IS2D = f'{IS}3d'

# %% ../nbs/61_tens.ipynb 28
INIT = 'init'
NINIT = f'n{INIT}'
N_INIT = f'n_{INIT}'

# %% ../nbs/61_tens.ipynb 29
IS_BUILT = 'is_built'
IS_AVAILABLE = 'is_available'

# %% ../nbs/61_tens.ipynb 30
SEED = 'seed'
SEEDS = f'{SEED}s'
SEEDED = f'{SEED}ed'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/54_docs.ipynb.

# %% auto 0
__all__ = ['NOTES', 'WARNS', 'RAISES', 'YIELDS', 'METHODS', 'RETURNS', 'EXAMPLES', 'RECEIVES', 'SEE_ALSO', 'ATTRIBUTES',
           'REFERENCES', 'PARAMETERS']

# %% ../nbs/54_docs.ipynb 4
NOTES = 'notes'
WARNS = 'warns'

RAISES = 'raises'
YIELDS = 'yields'

METHODS = 'methods'
RETURNS = 'returns'

EXAMPLES = 'examples'
RECEIVES = 'receives'
SEE_ALSO = 'see_also'

ATTRIBUTES = 'attributes'
REFERENCES = 'references'
PARAMETERS = 'parameters'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/62_pddf.ipynb.

# %% auto 0
__all__ = ['DF', 'DS', 'DX', 'DATA', 'ASTYPE', 'DATASET', 'DATAFRAME', 'IDX', 'INDEX', 'CAT', 'CATS', 'NCAT', 'CATEGORY',
           'CATEGORIES', 'CODE', 'CODES', 'COL', 'COLS', 'NCOL', 'COLUMNS', 'ROW', 'ROWS', 'NROW', 'GET', 'SHAPE',
           'LOC', 'CLOC', 'ILOC', 'ICAT', 'UNNAMED', 'UNNAMED_CLN']

# %% ../nbs/62_pddf.ipynb 5
from nchr import CLN

# %% ../nbs/62_pddf.ipynb 6
DF = 'df'
DS = 'ds'
DX = 'dx'
DATA = 'data'

ASTYPE = 'astype'
DATASET = f'{DATA}set'
DATAFRAME = f'{DATA}frame'

# %% ../nbs/62_pddf.ipynb 7
IDX = 'idx'
INDEX = 'index'

# %% ../nbs/62_pddf.ipynb 8
CAT = 'cat'
CATS = f'{CAT}s'
NCAT = f'n{CAT}'

CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/62_pddf.ipynb 9
CODE = 'code'
CODES = f'{CODE}s'

# %% ../nbs/62_pddf.ipynb 10
COL = 'col'
COLS = f'{COL}s'
NCOL = f'n{COL}'
COLUMNS = f'{COL}umns'

# %% ../nbs/62_pddf.ipynb 11
ROW = 'row'
ROWS = f'{ROW}s'
NROW = f'n{ROW}'

# %% ../nbs/62_pddf.ipynb 12
GET = 'get'
SHAPE = f'shape'

# %% ../nbs/62_pddf.ipynb 13
LOC = 'loc'
CLOC = f'c{LOC}'
ILOC = f'i{LOC}'
ICAT = f'i{CAT}'

# %% ../nbs/62_pddf.ipynb 14
UNNAMED = 'unnamed'

UNNAMED_CLN = f'{UNNAMED}{CLN}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/30_exps.ipynb.

# %% auto 0
__all__ = ['ID', 'IDX', 'ITEM', 'NAME', 'SEED', 'BATCH', 'LABEL', 'TOTAL', 'METHOD', 'PCT', 'PERCENT', 'DAY', 'TIME', 'TIMEPOINT',
           'TIMEPOINTS', 'CNT', 'COUNT', 'NORM', 'NORMALIZED', 'CON', 'COND', 'CONDITION', 'CONDITIONS', 'REP', 'REPL',
           'REPLICATE', 'SMP', 'SMPL', 'SAMP', 'SAMPLE', 'SAMPLES', 'SAMPLE_IDX', 'TREATMENT', 'TREATMENTS', 'SENS',
           'SENSITIVITY', 'SENSITIVITIES', 'CAT', 'CATS', 'CATEGORY', 'CATEGORIES', 'FEAT', 'FEATURE', 'FEATURES',
           'FEATURE_TYPE', 'CLST', 'LEIDEN', 'CLUSTER', 'LOUVAIN', 'CLUSTERS', 'MAX_CLUSTERS', 'CLIP', 'SUB', 'SSET',
           'SUBSET', 'REPLACE', 'SD', 'SD1', 'SD2', 'SD3', 'SAMPLE_NAME', 'CONDITION_REPLICATE', 'CONDITION_TIMEPOINT',
           'COND_REPL', 'COND_TIME', 'CR', 'CT', 'CRT', 'OP', 'DATA', 'DIFF', 'DEG', 'DEGREE', 'KERN', 'KERNEL',
           'DEGREES', 'DIFF_OP', 'POT', 'POTENTIAL', 'DIFF_POT', 'DIFF_POTENTIAL', 'AFF', 'AFFINITY', 'KERNEL_DEGREE']

# %% ../nbs/30_exps.ipynb 4
from nchr import S_, U1

# %% ../nbs/30_exps.ipynb 6
ID = 'id'
IDX = 'idx'

# %% ../nbs/30_exps.ipynb 7
ITEM = 'item'
NAME = 'name'
SEED = 'seed'

# %% ../nbs/30_exps.ipynb 8
BATCH = 'batch'
LABEL = 'label'
TOTAL = 'total'

# %% ../nbs/30_exps.ipynb 9
METHOD = 'method'

# %% ../nbs/30_exps.ipynb 10
PCT = 'pct'
PERCENT = 'percent'

# %% ../nbs/30_exps.ipynb 11
DAY = 'day'
TIME = 'time'
TIMEPOINT = f'{TIME}point'
TIMEPOINTS = f'{TIMEPOINT}s'

# %% ../nbs/30_exps.ipynb 12
CNT = 'cnt'
COUNT = 'count'

# %% ../nbs/30_exps.ipynb 13
NORM = 'norm'
NORMALIZED = f'{NORM}alized'

# %% ../nbs/30_exps.ipynb 14
CON = 'con'
COND = f'{CON}d'
CONDITION = f'{COND}ition'
CONDITIONS = f'{CONDITION}s'

# %% ../nbs/30_exps.ipynb 15
REP = 'rep'
REPL = f'{REP}l'
REPLICATE = f'{REPL}icate'

# %% ../nbs/30_exps.ipynb 16
SMP = 'smp'
SMPL = f'{SMP}l'

SAMP = 'samp'
SAMPLE = f'{SAMP}le'
SAMPLES = f'{SAMPLE}s'

SAMPLE_IDX = f'{SAMPLE}{U1}{IDX}'

# %% ../nbs/30_exps.ipynb 17
TREATMENT = f'treatment'
TREATMENTS = f'{TREATMENT}s'

# %% ../nbs/30_exps.ipynb 18
SENS = 'sens'
SENSITIVITY = f'{SENS}itivity'
SENSITIVITIES = f'{SENS}itivities'

# %% ../nbs/30_exps.ipynb 19
CAT = 'cat'
CATS = f'{CAT}s'
CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/30_exps.ipynb 20
FEAT = 'feat'
FEATURE = f'{FEAT}ure'
FEATURES = f'{FEATURE}s'
FEATURE_TYPE = f'{FEATURE}_type'

# %% ../nbs/30_exps.ipynb 21
CLST = 'clst'
LEIDEN = 'leiden'
CLUSTER = 'cluster'
LOUVAIN = 'louvain'

CLUSTERS = f'{CLUSTER}s'

# %% ../nbs/30_exps.ipynb 22
MAX_CLUSTERS = f'max_{CLUSTERS}'

# %% ../nbs/30_exps.ipynb 23
CLIP = 'clip'

# %% ../nbs/30_exps.ipynb 24
SUB = 'sub'
SSET = 'sset'
SUBSET = 'subset'
REPLACE = 'replace'

# %% ../nbs/30_exps.ipynb 25
SD = 'sd'
SD1 = f'{SD}1'
SD2 = f'{SD}2'
SD3 = f'{SD}3'

# %% ../nbs/30_exps.ipynb 26
SAMPLE_NAME = f'{SAMPLE}{U1}{NAME}'

CONDITION_REPLICATE = f'{CONDITION}{U1}{REPLICATE}'
CONDITION_TIMEPOINT = f'{CONDITION}{U1}{TIMEPOINT}'

COND_REPL = f'{COND}{U1}{REPL}'
COND_TIME = f'{COND}{U1}{TIME}'

# %% ../nbs/30_exps.ipynb 27
CR = 'ct'
CT = 'cr'
CRT = 'crt'

# %% ../nbs/30_exps.ipynb 28
OP = 'op'
DATA = 'data'
DIFF = 'diff'

DEG = 'deg'
DEGREE = f'{DEG}ree'

KERN = 'kern'
KERNEL = f'{KERN}el'

DEGREES = f'{DEGREE}s'
DIFF_OP = f'{DIFF}_{OP}'

POT = 'pot'
POTENTIAL = f'{POT}ential'
DIFF_POT = f'{DIFF}_{POT}'
DIFF_POTENTIAL = f'{DIFF}_{POTENTIAL}'


AFF = 'aff'
AFFINITY = f'{AFF}inity'

KERNEL_DEGREE = f'{KERNEL}_{DEGREE}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'IS', 'TO', 'DF', 'DS', 'DX', 'ALT', 'HAS', 'GET', 'GOT', 'SET', 'GEN', 'CON', 'DEC', 'IDX', 'SEP', 'FMT', 'KEY',
           'POS', 'CAT', 'ERR', 'RET', 'MSG', 'ATTR', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SHOW', 'PREF',
           'KEYS', 'PREP', 'PROP', 'DECO', 'LINK', 'PATH', 'PROPS', 'ATTRS', 'TYPES', 'FUNCS', 'COORD', 'SLICE',
           'START', 'STOP', 'STEP', 'LIST', 'TUPLE', 'HUSH', 'SELF', 'QUIET', 'RAISE', 'FAILQ', 'SPEC', 'SPECS', 'ANTI',
           'PTTN', 'PATTERN', 'ANTI_PTTN', 'DEBUG', 'PRINT', 'VALUE', 'GUARD', 'ERROR', 'COLOR', 'LABEL', 'TITLE',
           'NBINS', 'CUTOFF', 'MIXINS', 'UNIQUE', 'HIDDEN', 'IGNORE', 'ORIGIN', 'DEFAULT', 'INPLACE', 'VERBOSE',
           'REVERSE', 'EXCLUDE', 'SPECIAL', 'OPTIONAL', 'REQUIRED', 'ASMEMBER', 'ABRV', 'SYMB', 'CONS', 'FMTFUNC',
           'MOD', 'PKG', 'ARG', 'KWS', 'VAR', 'KWDS', 'ARGS', 'KWARGS', 'VARS', 'VARG', 'VKWS', 'VARGS', 'VKWDS',
           'VKWARGS', 'DROP', 'DROPNONE', 'BEG', 'END', 'NEG', 'LEN', 'DIG', 'BRV', 'FIX', 'PREFIX', 'SUFFIX', 'STRS',
           'SUNDER', 'DUNDER', 'MANGLED', 'PRIVATE', 'CHAR', 'PROPERTY', 'OVERWRITE', 'OVERWRITABLE', 'ALTS', 'ALTER',
           'ALTERNATES', 'FPS', 'PXS', 'VID', 'PTS', 'FCS', 'FCE', 'FRS', 'FRE', 'DATA', 'META', 'VIDEO', 'METADATA',
           'VIDEO_META', 'VIDEO_FPS', 'VALUES', 'VIDPXS', 'SUBPXS', 'BBOX', 'PTS_UNIT', 'START_PTS', 'END_PTS', 'SEC',
           'CODEC', 'OPTIONS', 'VIDEO_CODEC', 'AUDIO', 'ARRAY', 'AUDIO_FPS', 'AUDIO_ARRAY', 'AUDIO_CODEC',
           'AUDIO_OPTIONS']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
IS = 'is'
TO = 'to'

# %% ../nbs/02_args.ipynb 7
DF = 'df'
DS = 'ds'
DX = 'dx'

# %% ../nbs/02_args.ipynb 8
ALT = 'alt'
HAS = 'has'
GET = 'get'
GOT = 'got'
SET = 'set'

# %% ../nbs/02_args.ipynb 9
GEN = 'gen'
CON = 'con'
DEC = 'dec'

# %% ../nbs/02_args.ipynb 10
IDX = 'idx'
SEP = 'sep'
FMT = 'fmt'
KEY = 'key'
POS = 'pos'
CAT = 'cat'

# %% ../nbs/02_args.ipynb 11
ERR = 'err'
RET = 'ret'
MSG = 'msg'

# %% ../nbs/02_args.ipynb 12
ATTR = 'attr'
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'
SHOW = 'show'
PREF = 'pref'
KEYS = 'keys'
PREP = 'prep'
PROP = 'prop'
DECO = 'deco'


# %% ../nbs/02_args.ipynb 13
LINK = 'link'
PATH = 'path'

# %% ../nbs/02_args.ipynb 14
PROPS = f'{PROP}s'
ATTRS = f'{ATTR}s'
TYPES = f'{TYPE}s'
FUNCS = f'{FUNC}s'

# %% ../nbs/02_args.ipynb 15
COORD = 'coord'
SLICE = 'slice'

# %% ../nbs/02_args.ipynb 16
START = 'start'
STOP = 'stop'
STEP = 'step'

LIST = 'list'
TUPLE = 'tuple'

# %% ../nbs/02_args.ipynb 17
HUSH = 'hush'
SELF = 'self'

QUIET = 'quiet'
RAISE = 'raise'
FAILQ = 'failq'

# %% ../nbs/02_args.ipynb 18
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 19
ANTI = 'anti'
PTTN = 'pttn'
PATTERN = 'pattern'

ANTI_PTTN = f'{ANTI}_{PTTN}'

# %% ../nbs/02_args.ipynb 20
DEBUG = 'debug'
PRINT = 'print'
VALUE = 'value'
GUARD = 'guard'
ERROR = 'error'

COLOR = 'color'
LABEL = 'label'
TITLE = 'title'

NBINS = 'nbins'

# %% ../nbs/02_args.ipynb 21
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 22
HIDDEN = 'hidden'
IGNORE = 'ignore'
ORIGIN = 'origin'

# %% ../nbs/02_args.ipynb 23
DEFAULT = 'default'
INPLACE = 'inplace'
VERBOSE = 'verbose'
REVERSE = 'reverse'
EXCLUDE = 'exclude'
SPECIAL = 'special'

# %% ../nbs/02_args.ipynb 24
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 26
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 28
ABRV = 'abrv'
SYMB = 'symb'

CONS = 'cons'

# %% ../nbs/02_args.ipynb 29
FMTFUNC = f'{FMT}{FUNC}'

# %% ../nbs/02_args.ipynb 32
MOD = 'mod'
PKG = 'pkg'

# %% ../nbs/02_args.ipynb 34
ARG = 'arg'
KWS = 'kws'
VAR = 'var'
KWDS = 'kwds'
ARGS = f'{ARG}s'
KWARGS = f'kw{ARGS}'
VARS = f'{VAR}s'
VARG = f'v{ARG}'
VKWS = f'v{KWS}'
VARGS = f'v{ARGS}'
VKWDS = f'v{KWDS}'
VKWARGS = f'v{KWARGS}'
SELF = 'self'

# %% ../nbs/02_args.ipynb 35
DROP = 'drop'
DROPNONE = f'{DROP}none'


# %% ../nbs/02_args.ipynb 37
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix

PREFIX = f'pre{FIX}'
SUFFIX = f'suf{FIX}'

STRS = 'strs'

# %% ../nbs/02_args.ipynb 38
SUNDER = 'sunder'
DUNDER = 'dunder'
MANGLED = 'mangled'
PRIVATE = 'private'

# %% ../nbs/02_args.ipynb 39
CHAR = 'char'


# %% ../nbs/02_args.ipynb 41
PROP = 'prop'
PROPS = f'{PROP}s'
PROPERTY = f'{PROP}erty'

# %% ../nbs/02_args.ipynb 43
OVERWRITE = 'overwrite'
OVERWRITABLE = 'overwritable'

# %% ../nbs/02_args.ipynb 44
ALT = 'alt'
ALTS = f'{ALT}s'
ALTER = 'alter'
ALTERNATES = f'{ALTER}nates'

# %% ../nbs/02_args.ipynb 46
FPS = 'fps'
PXS = 'pxs'
VID = 'vid'
PTS = 'pts'

FCS = 'fcs'
FCE = 'fce'
FRS = 'frs'
FRE = 'fre'

DATA = 'data'
META = 'meta'
VIDEO = 'video'

METADATA = f'{META}{DATA}'
VIDEO_META = f'{VIDEO}_{META}'
VIDEO_FPS = f'{VIDEO}_{FPS}'

VALUES = 'values'
VIDPXS = f'vid{PXS}' 
SUBPXS = f'sub{PXS}'

BBOX = 'bbox'
LABEL = 'label'
IGNORE = 'ignore'
PTS_UNIT = f'{PTS}_unit'
START_PTS = f'start_{PTS}'
END_PTS = f'end_{PTS}'
SEC = 'sec'

CODEC = 'codec'
OPTIONS = 'options'
VIDEO_CODEC = f'{VIDEO}_{CODEC}'

AUDIO = 'audio'
ARRAY = 'array'
AUDIO_FPS = f'{AUDIO}_{FPS}'
AUDIO_ARRAY = f'{AUDIO}_{ARRAY}'
AUDIO_CODEC = f'{AUDIO}_{CODEC}'
AUDIO_OPTIONS = f'{AUDIO}_{OPTIONS}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/51_exts.ipynb.

# %% auto 0
__all__ = ['GZ', 'H5', 'PT', 'PY', 'BED', 'CSV', 'MTX', 'TAR', 'TSV', 'NPY', 'NPZ', 'TXT', 'PIP', 'PTH', 'YML', 'ZIP', 'JSON',
           'H5AD', 'IPYNB', 'ARROW', 'FASTA', 'PARQUET', 'AVI', 'GIF', 'EXT_GZ', 'EXT_H5', 'EXT_PT', 'EXT_PY',
           'EXT_BED', 'EXT_CSV', 'EXT_MTX', 'EXT_TAR', 'EXT_TSV', 'EXT_NPY', 'EXT_NPZ', 'EXT_TXT', 'EXT_PIP', 'EXT_PTH',
           'EXT_YML', 'EXT_ZIP', 'EXT_JSON', 'EXT_H5AD', 'EXT_IPYNB', 'EXT_ARROW', 'EXT_FASTA', 'EXT_PARQUET',
           'EXT_TAR_GZ', 'EXT_AVI', 'EXT_GIF']

# %% ../nbs/51_exts.ipynb 4
from nchr import PERIOD

# %% ../nbs/51_exts.ipynb 6
GZ = f'gz'
H5 = f'h5'
PT = f'pt'
PY = f'py'

BED = f'bed'
CSV = f'csv'
MTX = f'mtx'
TAR = f'tar'
TSV = f'tsv'
NPY = f'npy'
NPZ = f'npz'
TXT = f'txt'
PIP = f'pip'
PTH = f'pth'
YML = f'yml'
ZIP = f'zip'

JSON = f'json'
H5AD = f'h5ad'
IPYNB = f'ipynb'

ARROW = 'arrow'
FASTA = 'fasta'
PARQUET = 'parquet'


AVI = 'avi'
GIF = f'gif'


# %% ../nbs/51_exts.ipynb 8
EXT_GZ = f'{PERIOD}{GZ}'
EXT_H5 = f'{PERIOD}{H5}'
EXT_PT = f'{PERIOD}{PT}'
EXT_PY = f'{PERIOD}{PY}'

EXT_BED = f'{PERIOD}{BED}'
EXT_CSV = f'{PERIOD}{CSV}'
EXT_MTX = f'{PERIOD}{MTX}'
EXT_TAR = f'{PERIOD}{TAR}'
EXT_TSV = f'{PERIOD}{TSV}'
EXT_NPY = f'{PERIOD}{NPY}'
EXT_NPZ = f'{PERIOD}{NPZ}'
EXT_TXT = f'{PERIOD}{TXT}'
EXT_PIP = f'{PERIOD}{PIP}'
EXT_PTH = f'{PERIOD}{PTH}'
EXT_YML = f'{PERIOD}{YML}'
EXT_ZIP = f'{PERIOD}{ZIP}'

EXT_JSON = f'{PERIOD}{JSON}'
EXT_H5AD = f'{PERIOD}{H5AD}'
EXT_IPYNB = f'{PERIOD}{IPYNB}'

EXT_ARROW = f'{PERIOD}{ARROW}'
EXT_FASTA = f'{PERIOD}{FASTA}'

EXT_PARQUET = f'{PERIOD}{PARQUET}'

EXT_TAR_GZ = f'{EXT_TAR}{EXT_GZ}'

EXT_AVI = f'{PERIOD}{AVI}'
EXT_GIF = f'{PERIOD}{GIF}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/05_vals.ipynb.

# %% auto 0
__all__ = ['OBJ', 'KWS', 'CLS', 'NEW', 'INI', 'ANN', 'SUP', 'DEF', 'INS', 'OBJVAL', 'KWSVAL', 'CLSVAL', 'NEWVAL', 'INIVAL',
           'ANNVAL', 'SUPVAL', 'DEFVAL']

# %% ../nbs/05_vals.ipynb 5
OBJ = 'obj' # instance
KWS = 'kws' # kwargs
CLS = 'cls' # class
NEW = 'new' # new
INI = 'ini' # init
ANN = 'ann' # annotation
SUP = 'sup' # super
DEF = 'sef' # default


INS = 'ins' # instance

# %% ../nbs/05_vals.ipynb 6
OBJVAL = f'{OBJ}val'
KWSVAL = f'{KWS}val'
CLSVAL = f'{CLS}val'
NEWVAL = f'{NEW}val'
INIVAL = f'{INI}val'
ANNVAL = f'{ANN}val'
SUPVAL = f'{SUP}val'
DEFVAL = f'{DEF}val'
